AnnotationManager<T extends Annotation> class abstract

Implementers

Constructors

AnnotationManager(VietmapController controller, {void onTap(T)?, int selectLayer(T)?, required bool enableInteraction})

Properties

allLayerProperties → List<LayerProperties>
implemented to define the layer properties
no setter
annotations → Set<T>
no setter
controller → VietmapController
final
enableInteraction → bool
If disabled the manager offers no interaction for the created symbols
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
base id of the manager. User layerdIds to get the actual ids.
final
layerIds → List<String>
no setter
onTap → void Function(T)?
Called if a annotation is tapped
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectLayer → int Function(T)?
used to spedicy the layer and annotation will life on This can be replaced by layer filters a soon as they are implemented
final

Methods

add(T annotation) → Future<void>
add a single annotation to the map
addAll(Iterable<T> annotations) → Future<void>
Adds a multiple annotations to the map. This much faster than calling add multiple times
byId(String id) → T?
get the an annotation by its id
clear() → Future<void>
Removes all annotations from the map
dispose() → Future<void>
Fully dipose of all the the resouces managed by the annotation manager. The manager cannot be used after this has been called
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(T annotation) → Future<void>
Remove a single annotation form the map
removeAll(Iterable<T> annotations) → Future<void>
Removes multiple annotations from the map
set(T anntotation) → Future<void>
Set an existing anntotation to the map. Use this to do a fast update for a single annotation
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited