CircleOptions class

Configuration options for Circle instances.

When used to change configuration, null values will be interpreted as "do not change this configuration option".

Constructors

CircleOptions({double? circleRadius, Color? circleColor, double? circleBlur, double? circleOpacity, double? circleStrokeWidth, Color? circleStrokeColor, double? circleStrokeOpacity, LatLng? geometry, bool? draggable})
Creates a set of circle configuration options.
const

Properties

circleBlur → double?
final
circleColor → Color?
final
circleOpacity → double?
final
circleRadius → double?
final
circleStrokeColor → Color?
final
circleStrokeOpacity → double?
final
circleStrokeWidth → double?
final
draggable → bool?
final
geometry → LatLng?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith(CircleOptions changes) → CircleOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toGeoJson() → Map<String, dynamic>
toJson([bool addGeometry = true]) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultOptions → const CircleOptions