ImageSourceProperties class

Implemented types

Constructors

ImageSourceProperties({String? url, List<List>? coordinates})
const
ImageSourceProperties.fromJson(Map<String, dynamic> json)
factory

Properties

coordinates → List<List>?
Corners of image specified in longitude, latitude pairs.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String?
URL that points to an image.
final

Methods

copyWith(String? url, List<List>? coordinates) → ImageSourceProperties
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited