LocationEngineAndroidProperties class

Annotations

Constructors

LocationEngineAndroidProperties({required int interval, required int displacement, required LocationPriority priority})
const

Properties

displacement → int
The minimum displacement in meters for location updates.
final
hashCode → int
The hash code for this object.
no setteroverride
interval → int
The interval in milliseconds for location updates.
final
priority → LocationPriority
LocationPriority.highAccuracy only uses native GPS provider LocationPriority.balanced uses a fused provider (network + GPS)-> better quality indoor LocationPriority.lowPower only uses network provider LocationPriority.noPower only receives location updates when another clients request them
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? interval, int? displacement, LocationPriority? priority}) → LocationEngineAndroidProperties
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toList() → List<int>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override