LocationEnginePlatforms class

iOS is not supported at the moment.

Annotations

Constructors

LocationEnginePlatforms({LocationEngineAndroidProperties androidPlatform = LocationEngineAndroidProperties.defaultProperties})
If androidPlatform is not provided, it defaults to LocationEngineAndroidProperties.defaultProperties.
const

Properties

androidPlatform → LocationEngineAndroidProperties
The properties for the Android platform.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toList() → List<int>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited