MethodChannelVietmapGl class

Inheritance

Constructors

MethodChannelVietmapGl()

Properties

hashCode → int
The hash code for this object.
no setterinherited
onAnnotationUpdate → ArgumentCallbacks<Map<String, dynamic>>
finalinherited
onCameraIdlePlatform → ArgumentCallbacks<CameraPosition?>
finalinherited
onCameraMovePlatform → ArgumentCallbacks<CameraPosition>
finalinherited
onCameraMoveStartedPlatform → ArgumentCallbacks<void>
finalinherited
onCameraTrackingChangedPlatform → ArgumentCallbacks<MyLocationTrackingMode>
finalinherited
onCameraTrackingDismissedPlatform → ArgumentCallbacks<void>
finalinherited
onDidFinishedRenderingFrame → ArgumentCallbacks<void>
finalinherited
onFeatureDraggedPlatform → ArgumentCallbacks<Map<String, dynamic>>
finalinherited
onFeatureHoverPlatform → ArgumentCallbacks<Map<String, dynamic>>
Fired when the pointer enters, moves over, or leaves an interactive feature.
finalinherited
onFeatureTappedPlatform → ArgumentCallbacks<Map<String, dynamic>>
finalinherited
onInfoWindowTappedPlatform → ArgumentCallbacks<String>
finalinherited
onMapClickPlatform → ArgumentCallbacks<Map<String, dynamic>>
finalinherited
onMapIdlePlatform → ArgumentCallbacks<void>
finalinherited
onMapLongClickPlatform → ArgumentCallbacks<Map<String, dynamic>>
finalinherited
onMapRenderedPlatform → ArgumentCallbacks<void>
finalinherited
onMapStyleLoadedPlatform → ArgumentCallbacks<void>
finalinherited
onUserLocationUpdatedPlatform → ArgumentCallbacks<UserLocation>
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCircleLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom, dynamic filter, required bool enableInteraction}) → Future<void>
override
addFillExtrusionLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom, dynamic filter, required bool enableInteraction}) → Future<void>
override
addFillLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom, dynamic filter, required bool enableInteraction}) → Future<void>
override
addGeoJsonSource(String sourceId, Map<String, dynamic> geojson, {String? promoteId}) → Future<void>
override
addHeatmapLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom}) → Future<void>
override
addHillshadeLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom}) → Future<void>
override
addImage(String name, Uint8List bytes, [bool sdf = false]) → Future<void>
override
addImageSource(String imageSourceId, Uint8List bytes, LatLngQuad coordinates) → Future<void>
override
addLayer(String imageLayerId, String imageSourceId, double? minzoom, double? maxzoom) → Future<void>
override
addLayerBelow(String imageLayerId, String imageSourceId, String belowLayerId, double? minzoom, double? maxzoom) → Future<void>
override
addLineLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom, dynamic filter, required bool enableInteraction}) → Future<void>
override
addRasterLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom}) → Future<void>
override
addSource(String sourceId, SourceProperties properties) → Future<void>
override
addSymbolLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom, dynamic filter, required bool enableInteraction}) → Future<void>
override
animateCamera(CameraUpdate cameraUpdate, {Duration? duration}) → Future<bool?>
override
buildView(Map<String, dynamic> creationParams, OnPlatformViewCreatedCallback onPlatformViewCreated, Set<Factory<OneSequenceGestureRecognizer>>? gestureRecognizers) → Widget
override
clearAmbientCache() → Future
override
dispose() → void
override
easeCamera(CameraUpdate cameraUpdate, {Duration? duration, CameraAnimationInterpolation? interpolation}) → Future<bool?>
Eases the camera with an explicit easing curve.
override
forceResizeWebMap() → void
override
getFilter(String layerId) → Future
override
getLayerIds() → Future<List>
override
getMetersPerPixelAtLatitude(double latitude) → Future<double>
override
getSourceIds() → Future<List>
override
getTelemetryEnabled() → Future<bool>
override
getVisibleRegion() → Future<LatLngBounds>
override
initPlatform(int id) → Future<void>
override
invalidateAmbientCache() → Future
override
matchMapLanguageWithDeviceDefault() → Future<void>
override
moveCamera(CameraUpdate cameraUpdate) → Future<bool?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryRenderedFeatures(Point<double> point, List<String>? layerIds, List<Object>? filter) → Future<List>
override
queryRenderedFeaturesInRect(Rect rect, List<String> layerIds, String? filter) → Future<List>
override
querySourceFeatures(String sourceId, String? sourceLayerId, List<Object>? filter) → Future<List>
override
recenter() → Future<void>
override
removeLayer(String imageLayerId) → Future<void>
override
removeSource(String sourceId) → Future<void>
override
requestMyLocationLatLng() → Future<LatLng?>
override
resizeWebMap() → void
override
setCameraBounds({required double west, required double north, required double south, required double east, required int padding}) → Future
override
setFeatureForGeoJsonSource(String sourceId, Map<String, dynamic> geojsonFeature) → Future<void>
override
setFilter(String layerId, dynamic filter) → Future<void>
override
setGeoJsonSource(String sourceId, Map<String, dynamic> geojson) → Future<void>
override
setLayerProperties(String layerId, Map<String, dynamic> properties) → Future<void>
override
setLayerVisibility(String layerId, bool visible) → Future<void>
override
setMapLanguage(String language) → Future<void>
override
setStyle(String style) → Future<void>
override
setTelemetryEnabled(bool enabled) → Future<void>
override
takeSnapshot({int? width, int? height}) → Future<Uint8List>
Takes a snapshot of the current map and returns it as PNG bytes.
override
toLatLng(Point<num> screenLocation) → Future<LatLng>
override
toScreenLocation(LatLng latLng) → Future<Point<num>>
override
toScreenLocationBatch(Iterable<LatLng> latLngs) → Future<List<Point<num>>>
override
toString() → String
A string representation of this object.
inherited
updateContentInsets(EdgeInsets insets, bool animated) → Future<void>
override
updateImageSource(String imageSourceId, Uint8List? bytes, LatLngQuad? coordinates) → Future<void>
override
updateLayerProperties(MarkerLayerPositionData data) → Future<void>
override
updateLogoEnabled(bool isEnable) → Future<void>
override
updateMapOptions(Map<String, dynamic> optionsUpdate) → Future<CameraPosition?>
override
updateMyLocationTrackingMode(MyLocationTrackingMode myLocationTrackingMode) → Future<void>
override
updateUserLocationLayerIcon(bool isEnable) → Future<void>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

useHybridComposition ↔ bool
getter/setter pair