PolygonOptions class

Configuration options for Polygon instances.

When used to change configuration, null values will be interpreted as "do not change this configuration option".

Constructors

PolygonOptions({double? polygonOpacity, Color? polygonColor, Color? polygonOutlineColor, String? polygonPattern, List<List<LatLng>>? geometry, bool? draggable})
Creates a set of fill configuration options.
const

Properties

draggable → bool?
final
geometry → List<List<LatLng>>?
final
hashCode → int
The hash code for this object.
no setterinherited
polygonColor → Color?
final
polygonOpacity → double?
final
polygonOutlineColor → Color?
final
polygonPattern → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith(PolygonOptions changes) → PolygonOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toGeoJson() → Map<String, dynamic>
toJson([bool addGeometry = true]) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultOptions → const PolygonOptions