PolylineAnimation class

Constructors

PolylineAnimation(List<LatLng> listLatLng)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalDistance → dynamic
no setter

Methods

coordinateFromStart(double distance) → Feature<Point>
findNearestFloorIndex(double currentDistance) → int
get(dynamic index) → Point
makeLineString(List<LatLng> latLng) → Feature<LineString>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited