Symbol class

Implemented types

Constructors

Symbol(String _id, SymbolOptions options, [Map? _data])

Properties

data → Map?
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setteroverride
options ↔ SymbolOptions
The symbol configuration options most recently applied programmatically via the map controller.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toGeoJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited
translate(LatLng delta) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited