SymbolManager class

Inheritance

Constructors

SymbolManager(VietmapController controller, {void onTap(Symbol)?, bool iconAllowOverlap = false, bool textAllowOverlap = false, bool iconIgnorePlacement = false, bool textIgnorePlacement = false, bool enableInteraction = true})

Properties

allLayerProperties → List<LayerProperties>
implemented to define the layer properties
no setteroverride
annotations → Set<Symbol>
no setterinherited
controller → VietmapController
finalinherited
enableInteraction → bool
If disabled the manager offers no interaction for the created symbols
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
base id of the manager. User layerdIds to get the actual ids.
finalinherited
layerIds → List<String>
no setterinherited
onTap → void Function(Symbol)?
Called if a annotation is tapped
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectLayer → int Function(Symbol)?
used to spedicy the layer and annotation will life on This can be replaced by layer filters a soon as they are implemented
finalinherited

Methods

add(Symbol annotation) → Future<void>
add a single annotation to the map
inherited
addAll(Iterable<Symbol> annotations) → Future<void>
Adds a multiple annotations to the map. This much faster than calling add multiple times
inherited
byId(String id) → Symbol?
get the an annotation by its id
inherited
clear() → Future<void>
Removes all annotations from the map
inherited
dispose() → Future<void>
Fully dipose of all the the resouces managed by the annotation manager. The manager cannot be used after this has been called
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(Symbol annotation) → Future<void>
Remove a single annotation form the map
inherited
removeAll(Iterable<Symbol> annotations) → Future<void>
Removes multiple annotations from the map
inherited
set(Symbol anntotation) → Future<void>
Set an existing anntotation to the map. Use this to do a fast update for a single annotation
inherited
setIconAllowOverlap(bool value) → Future<void>
If true, the icon will be visible even if it collides with other previously drawn symbols.
setIconIgnorePlacement(bool value) → Future<void>
If true, the text will be visible even if it collides with other previously drawn symbols.
setTextAllowOverlap(bool value) → Future<void>
If true, other symbols can be visible even if they collide with the icon.
setTextIgnorePlacement(bool value) → Future<void>
If true, other symbols can be visible even if they collide with the text.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited