SymbolOptions class

Configuration options for Symbol instances.

When used to change configuration, null values will be interpreted as "do not change this configuration option".

Constructors

SymbolOptions({double? iconSize, String? iconImage, double? iconRotate, Offset? iconOffset, String? iconAnchor, List<String>? fontNames, String? textField, double? textSize, double? textMaxWidth, double? textLetterSpacing, String? textJustify, String? textAnchor, double? textRotate, String? textTransform, Offset? textOffset, double? iconOpacity, Color? iconColor, Color? iconHaloColor, double? iconHaloWidth, double? iconHaloBlur, double? textOpacity, Color? textColor, Color? textHaloColor, double? textHaloWidth, double? textHaloBlur, LatLng? geometry, int? zIndex, bool? draggable})
Creates a set of symbol configuration options.
const

Properties

draggable → bool?
final
fontNames → List<String>?
Not supported on web
final
geometry → LatLng?
final
hashCode → int
The hash code for this object.
no setterinherited
iconAnchor → String?
final
iconColor → Color?
final
iconHaloBlur → double?
final
iconHaloColor → Color?
final
iconHaloWidth → double?
final
iconImage → String?
final
iconOffset → Offset?
final
iconOpacity → double?
final
iconRotate → double?
final
iconSize → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textAnchor → String?
final
textColor → Color?
final
textField → String?
final
textHaloBlur → double?
final
textHaloColor → Color?
final
textHaloWidth → double?
final
textJustify → String?
final
textLetterSpacing → double?
final
textMaxWidth → double?
final
textOffset → Offset?
final
textOpacity → double?
final
textRotate → double?
final
textSize → double?
final
textTransform → String?
final
zIndex → int?
final

Methods

copyWith(SymbolOptions changes) → SymbolOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toGeoJson() → Map<String, dynamic>
toJson([bool addGeometry = true]) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultOptions → const SymbolOptions