UserLocation class

User's observed location

Constructors

UserLocation({required LatLng position, required double? altitude, required double? bearing, required double? speed, required double? horizontalAccuracy, required double? verticalAccuracy, required DateTime timestamp, required UserHeading? heading})
const

Properties

altitude → double?
User's altitude in meters
final
bearing → double?
Direction user is traveling, measured in degrees
final
hashCode → int
The hash code for this object.
no setterinherited
heading → UserHeading?
The heading of the user location, null if not available.
final
horizontalAccuracy → double?
The radius of uncertainty for the location, measured in meters
final
position → LatLng
User's position in latitude and longitude
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speed → double?
User's speed in meters per second
final
timestamp → DateTime
Time the user's location was observed
final
verticalAccuracy → double?
Accuracy of the altitude measurement, in meters
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited