VideoSourceProperties class

Implemented types

Constructors

VideoSourceProperties({List<String>? urls, List<List>? coordinates})
const
VideoSourceProperties.fromJson(Map<String, dynamic> json)
factory

Properties

coordinates → List<List>?
Corners of video specified in longitude, latitude pairs.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
urls → List<String>?
URLs to video content in order of preferred format.
final

Methods

copyWith(List<String>? urls, List<List>? coordinates) → VideoSourceProperties
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited