onCameraMove property

OnCameraMoveCallback? onCameraMove
final

Called continuously while the camera is moving, with the current CameraPosition.

On Android and iOS this requires trackCameraPosition to be true, otherwise the native side never emits intermediate camera positions.

Implementation

final OnCameraMoveCallback? onCameraMove;